define(
//begin v1.x content
{
	"scientificFormat": "#E0",
	"infinity": "∞",
	"superscriptingExponent": "×",
	"list": ";",
	"percentSign": "%",
	"minusSign": "−",
	"decimalFormat-short": "000 bill'.'",
	"nan": "NaN",
	"plusSign": "+",
	"currencyFormat": "¤ #,##0.00",
	"perMille": "‰",
	"approximatelySign": "ca.",
	"group": " ",
	"percentFormat": "#,##0 %",
	"decimalFormat-long": "000 billioner",
	"decimalFormat": "#,##0.###",
	"currencyFormat-short": "¤ 000 bill'.'",
	"timeSeparator": ".",
	"decimal": ",",
	"exponential": "E"
}
//end v1.x content
);